%define ALD_Ver		1.2.3

%define OrgName bash
Name:         uC-%{OrgName}

License:      GPL
Summary:      The GNU Bourne-Again Shell (build static-uClibc)
Group:        System Environment/Shells
Version:      3.2.57
Release:      1

Source: %{OrgName}-%{version}.tar.xz
Source1: CROSS-uC.sh
Patch0: %{OrgName}-%{version}.patch

%define DestDir		/Embedded/uC-%{uC_Version}
%define uC_Version 0.9.33.2

# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%define USE_LOCAL_CROSS 0
%else
# rpm --target=x86_64/armv6l -ba xxxxx.spec
%define _CROSS 1
%define USE_LOCAL_CROSS 1
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1

#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
ERROR: target=%{_os}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/usr/uC/%{uC_Version}/static/bin

%define __os_install_post %{nil}

%define _srcrpmdir %{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysdir %{nil}
%define csysbindir	/usr/uC/%{uC_Version}/static/bin
%define _srcrpmdir %{_topdir}/SRPMS/%{ALD_Ver}

%define target %{_arch}-uclibc

%endif # !_CROSS

%define _defaultdocdir %{_datadir}/doc
%define docdir %{_defaultdocdir}/%{OrgName}

# ------------------- description ------------------------------------
%description
Bash is a sh-compatible command interpreter
build static uClibc-0.9.33
LOCALES en_US en_GB de_DE de_AT de_BE de_CH de_LU fr_FR it_IT nl_NL
#-------------------------------
%package sh
Provides:     sh
Summary:       The GNU Bourne-Again Shell sh link
Group:        Documentation
%description sh
The GNU Bourne-Again Shell sh link
#-------------------------------
%package info
Summary:      Info for %{OrgName}
Group:        Documentation
%description info
Info for %{OrgName}
#-------------------------------
%package bug
Summary:      bashbug - create a bug report and mail it to the bug address
Group:        System Environment/Shells
%description bug
bashbug - create a bug report and mail it to the bug address

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{OrgName}-%{version}
%patch0 -b .orig -p0

# ------------------- Build ------------------------------------------
%Build
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
UCLIBC_GCC_INC_SKIP=%{csysdir}/usr/include
export PATH GCC_NoHostPath UCLIBC_GCC_INC_SKIP


%if %{_arch} == "i386"
OPTFLAGS="-Os -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-Os -fno-asynchronous-unwind-tables"
%endif
%if %{_arch} == "arm"
OPTFLAGS="-O2 -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
%endif

CFLAGS="$OPTFLAGS -DNeXT -ffunction-sections -fdata-sections -fno-tree-loop-optimize -fno-tree-dominator-opts -fno-strength-reduce -fno-stack-protector -std=gnu99"
LDFLAGS="-Wl,--gc-sections"
CFLAGS_FOR_BUILD="-Os"

export CFLAGS LDFLAGS CFLAGS_FOR_BUILD 

%if %{_CROSS}
# uClibc vars
export bash_cv_func_ctype_nonascii="yes"
export bash_cv_printf_a_format="no"

export bash_cv_getcwd_malloc="yes"
export ac_cv_c_bigendian="no"
export ac_cv_func_mmap_fixed_mapped="yes"
export ac_cv_func_working_mktime="no"
export ac_cv_func_strcoll_works="yes"
export ac_cv_type_getgroups="gid_t"
export gt_cv_int_divbyzero_sigfpe="yes"
export bash_cv_func_sigsetjmp="present"
export bash_cv_dup2_broken="no"
export bash_cv_getenv_redef="no"
export bash_cv_job_control_missing="present"
export bash_cv_pgrp_pipe="no"
export bash_cv_sys_siglist="no"
export bash_cv_type_rlimit="rlim_t"
export bash_cv_under_sys_siglist="yes"
export bash_cv_ulimit_maxfds="yes"
export bash_cv_opendir_not_robust="no"
export bash_cv_func_strcoll_broken="no"
export bash_cv_must_reinstall_sighandlers="no"
export bash_cv_sys_named_pipes="present"
export bash_cv_wcontinued_broken="no"
export bash_cv_unusable_rtsigs="no"

export ac_cv_path_GMSGFMT=":"
export ac_cv_path_MSGFMT=":"
export ac_cv_path_MSGMERGE=":"
export ac_cv_path_XGETTEXT=":"
%endif


./configure \
%if %{_CROSS}
	--build=%{_build} \
	--host=%{target} \
%endif
	--prefix= \
	--mandir=%{_mandir} \
	--infodir=%{_infodir} \
	--enable-arith-for-command \
	--disable-bang-history \
	--disable-net-redirections \
	--disable-progcomp \
	--enable-readline \
	--disable-restricted \
	--disable-select \
	--disable-profiling \
	--enable-static-link \
	--disable-nls \
	--without-lispdir \
	--without-afs \
	--without-bash-malloc \
	--without-purify \
	--disable-net-redirections \
	&>FConfigure_log.txt

make &>FMake_log.txt


# ------------------- Install ----------------------------------------
%Install
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>FInstall_log.txt

cp AUTHORS COMPAT COPYING NEWS POSIX RBASH README $RPM_BUILD_ROOT%{docdir}/

rm -rf $RPM_BUILD_ROOT%{_infodir}/dir

pushd $RPM_BUILD_ROOT/bin
  ln -s bash sh
popd

%if %{_CROSS}
TARGET_PRFIX=%{_prefix}
TARGET_CROSS_PRFIX=%{csysdir}
TARGET_NAME=%{target}
MKCROSSDIR=0
export TARGET_PRFIX TARGET_CROSS_PRFIX TARGET_NAME MKCROSSDIR
%SOURCE1
%endif #_CROSS

%if !%{_CROSS}
if test -f /opt/aldccp/bin/packages_idx; then
  /opt/aldccp/bin/packages_idx -p %{name} -v %{version} $RPM_BUILD_ROOT
fi
%endif

# ------------------- Clean ------------------------------------------
%Clean 

DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-sh-$SE $DD/%{name}-sh-$DE
  mv %{name}-info-$SE $DD/%{name}-info-$DE
  mv %{name}-bug-$SE $DD/%{name}-bug-$DE
popd

# --------------- build *.tgz ------------------------
%if %{BUILD_TAR}
pushd $RPM_BUILD_ROOT
  TMP_TO=$DD/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r bin usr $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
popd
%endif  #BUILD_TAR

# ------------------- Files ------------------------------------------

%Files
/bin/bash
%{_mandir}/man1/bash.1.gz
%{docdir}

%Files sh
/bin/sh

%files info
%{_infodir}

%files bug
/bin/bashbug
%{_mandir}/man1/bashbug.1.gz
